@@ -23,7 +23,8 @@ if (in_array("-db", $_SERVER["argv"], true)) {
   PHPUnit_Util_Filter::removeFileFromWhitelist(SABEL_BASE . DS . "sabel" . DS . "response" . DS . "header" . DS . "Http.php");
 }
 
-define("TEST_APP_DIR", SABEL_BASE . DS . "Test" . DS . "data" . DS . "application");
+define("TEST_DATA_DIR", SABEL_BASE . DS . "Test" . DS . "data");
+define("TEST_APP_DIR", TEST_DATA_DIR . DS . "application");
 define("MODULES_DIR_NAME", "app");
 define("VIEW_DIR_NAME",    "views");
 define("LOG_DIR_PATH",     TEST_APP_DIR . DS . "logs");
@@ -35,6 +36,7 @@ define("TEST",        0x05);
 define("DEVELOPMENT", 0x0A);
 define("ENVIRONMENT", TEST);
 define("TPL_SUFFIX",  ".tpl");
+define("SBL_SECURE_MODE", true);
 
 if (!defined("PHPUnit_MAIN_METHOD")) {
   define("PHPUnit_MAIN_METHOD", "SabelAllTests::main");
@@ -55,6 +57,8 @@ require_once ("Test/Application.php");
 require_once ("Test/Object.php");
 require_once ("Test/Console.php");
 require_once ("Test/Annotation.php");
+require_once ("Test/Aspect/Tests.php");
+require_once ("Test/Container.php");
 require_once ("Test/Exception.php");
 require_once ("Test/Bus/Tests.php");
 require_once ("Test/Request/Tests.php");
@@ -66,8 +70,11 @@ require_once ("Test/Map/Tests.php");
 require_once ("Test/Processor/Tests.php");
 require_once ("Test/Reflection.php");
 require_once ("Test/Cache/Tests.php");
+require_once ("Test/Mail/Tests.php");
 require_once ("Test/Session/Tests.php");
 require_once ("Test/Storage/Memory.php");
+require_once ("Test/VirtualInheritance.php");
+require_once ("Test/DB/TestConfig.php");
 require_once ("Test/DB/Statement/Tests.php");
 require_once ("Test/DB/Storage/Tests.php");
 require_once ("Test/DB/Tests.php");
@@ -104,12 +111,17 @@ class SabelAllTests
     $suite->addTest(Test_Cache_Tests::suite());
     $suite->addTest(Test_Session_Tests::suite());
     $suite->addTest(Test_Processor_Tests::suite());
+    
     $suite->addTest(Test_Annotation::suite());
     $suite->addTest(Test_Reflection::suite());
+    $suite->addTest(Test_Container::suite());
+    $suite->addTest(Test_Aspect_Tests::suite());
     $suite->addTest(Test_Exception::suite());
+    
     $suite->addTest(Test_Storage_Memory::suite());
     $suite->addTest(Test_I18n_Gettext::suite());
     $suite->addTest(Test_Cookie_Tests::suite());
+    $suite->addTest(Test_Mail_Tests::suite());
     
     $suite->addTest(Test_Application::suite());
     
