@@ -38,14 +38,7 @@ class Test_DB_Oci extends Test_DB_Test
   
   public function testInit()
   {
-    $params = array("package"  => "sabel.db.oci",
-                    "host"     => "127.0.0.1",
-                    "user"     => "develop",
-                    "password" => "develop",
-                    "database" => "XE",
-                    "charset"  => "UTF-8");
-    
-    Sabel_DB_Config::add("default", $params);
+    Sabel_DB_Config::add("default", Test_DB_TestConfig::getOciConfig());
     Test_DB_Test::$db = "ORACLE";
   }
 }
