@@ -537,10 +537,10 @@ Sabel.String = new Sabel.Class(String, {
 	},
 
 	format: function(obj) {
-		var pat = /(?:#\{(\w+)\}|%(\w+)%)/g;
-		return this._string.replace(pat, function(target, key) {
+		var replaceFunc = function(target, key) {
 			return (obj[key] !== undefined) ? obj[key] : "";
-		});
+		};
+		return this._string.replace(/%(\w+)%/g, replaceFunc).replace(/#\{(\w+)\}/g, replaceFunc);
 	},
 
 	ucfirst: function() {
@@ -901,7 +901,7 @@ Sabel.Dom.Selector = {
 			} else {
 				var el = document.getElementById(id);
 				for (var i = 0; i < nodes.length; i++) {
-					if (Sabel.Element.contains(nodes[i], el)) return [el];
+					if (Sabel.Element.isContain(nodes[i], el)) return [el];
 				}
 				return [];
 			}
@@ -1335,8 +1335,8 @@ Sabel.Element.getCumulativeTop = function(element) {
 		parent = element.offsetParent;
 
 		if (Sabel.UserAgent.isIE || Sabel.UserAgent.isMozilla) {
-			var border = parseInt(Sabel.Element.getStyle(parent, "borderTopWidth"));
-			position += border || 0;
+			var border = parseInt(Sabel.Element.getStyle(parent, "borderTopWidth")) || 0;
+			position += border;
 
 			if (Sabel.UserAgent.isMozilla) {
 				var of = Sabel.Element.getStyle(parent, "overflow");
@@ -1379,8 +1379,8 @@ Sabel.Element.getCumulativeLeft = function(element) {
 		parent = element.offsetParent;
 
 		if (Sabel.UserAgent.isOpera === false) {
-			var border = parseInt(Sabel.Element.getStyle(parent, "borderLeftWidth"));
-			position += border || 0;
+			var border = parseInt(Sabel.Element.getStyle(parent, "borderLeftWidth")) || 0;
+			position += border;
 
 			if (Sabel.UserAgent.isMozilla) {
 				var of = Sabel.Element.getStyle(parent, "overflow");
@@ -1563,12 +1563,14 @@ Sabel.Element.stopObserve = function(element, eventName, handler) {
 };
 
 Sabel.Element.analyze = function(element) {
-	var as = Sabel.get(element, false).attributes;
+	element = Sabel.get(element, false)
+	var as = element.attributes, buf = new Array(), attr, i = 0;
 
+	buf.push("<" + element.tagName.toLowerCase());
 	if (Sabel.UserAgent.isIE) {
 		var def = document.createElement(element.nodeName);
 
-		var buf = new Array(), attr, defAttr, i = 0;
+		var defAttr;
 		while (attr = as[i++]) {
 			if (typeof attr.nodeValue !== "string") continue;
 
@@ -1578,13 +1580,12 @@ Sabel.Element.analyze = function(element) {
 			buf[buf.length] = attr.nodeName + '="' + attr.nodeValue + '"';
 		}
 	} else {
-		var buf = new Array(), attr, i = 0;
 		while (attr = as[i++]) {
 			buf[buf.length] = attr.nodeName + '="' + attr.nodeValue + '"';
 		}
 	}
 
-	return buf.join(" ");
+	return buf.join(" ") + ">";
 };
 
 Sabel.Element.getChildElements = function(element, tagName) {
@@ -1694,7 +1695,7 @@ Sabel.Element._getOfTypeNodeIndex = function(element, reverse) {
 	return element[propName];
 };
 
-Sabel.Element.contains = function(element, other) {
+Sabel.Element.isContain = function(element, other) {
 	if (element === document) element = document.body;
 	if (element.contains) {
 		// IE, Opera, Safari
@@ -2098,27 +2099,24 @@ Sabel.Validator.prototype = {
 			if (v.validate() === false) errors.push(v.errMsg);
 		}
 
-		var status = !(errors.length);
-		if (status === false) {
+		this.clearMessageField();
+
+		if (errors.length !== 0) {
 			this.insertMessage(errors);
 			Sabel.Event.preventDefault(e);
-		} else {
-			this.clearMessageField();
 		}
 	},
 
 	insertMessage: function(errors) {
-		this.clearMessageField();
-
 		this.errField.appendChild(this.getErrorMessage(errors));
-		Sabel.Element.setStyle(this.errField, {display: "inline"});
+		Sabel.Element.show(this.errField);
 
 		var yPos = Sabel.Element.getCumulativeTop(this.errField) - 20;
 		window.scroll(0, yPos);
 	},
 
 	clearMessageField: function() {
-		Sabel.Element.setStyle(this.errField, {display: "none"});
+		Sabel.Element.hide(this.errField);
 		this.errField.innerHTML = "";
 	},
 
