@@ -44,6 +44,12 @@ class Sabel_DB_Mysql_Statement extends Sabel_DB_Statement
     return $values;
   }
   
+  public function createBlob($binary)
+  {
+    $conn = $this->driver->getConnection();
+    return new Sabel_DB_Mysql_Blob($conn, $binary);
+  }
+  
   public function quoteIdentifier($arg)
   {
     if (is_array($arg)) {
